@@ -69,7 +69,7 @@ def extractDocStrings(filepath: str) -> str:
         functions.append(class_)
 
     if len(functions) == 0:
-        return (retStr)
+        return tuple(retStr)
 
     for node in functions:
         if not isinstance(node, list):
@@ -96,7 +96,6 @@ def extractDocStrings(filepath: str) -> str:
             retStr += f"#### ``{className}``: {function.name}\n" # adding class name in function def w/ nested emphasis
             retStr += f"{functionDocString if functionDocString is not None else voidDocStringMSG}\n"
 
-
     return retStr
 
 def getPythonFiles(dir: str = None) -> list:
@@ -186,7 +185,7 @@ def main() -> None:
         help="Message for function without a DocString (enter 0 to exclude functions without a DocString entirely) (defaults to \"*No documentation provided.*\")")
     
     args = parser.parse_args()
-    
+
     try:
         GenDoc(args)
         print("Generated Successfully.")
